@@ -42,11 +42,11 @@ class Camera(BaseModel):
     )
 
     @model_validator(mode="after")
-    def validate_ptz_with_offsets(cls, model):
+    def validate_ptz_with_offsets(self):
         """Ensure that ptz_offsets is set when ptz is True."""
-        if model.ptz and not model.ptz_offsets:
+        if self.ptz and not self.ptz_offsets:
             raise ValueError("ptz_offsets cannot be empty when ptz is set to True")
-        return model
+        return self
 
 
 class GreenstreamConfig(BaseModel):
